@@ -2,6 +2,7 @@ import json
 import logging
 import os
 import subprocess
+import urllib.parse
 from collections import deque
 from dataclasses import asdict
 from dataclasses import dataclass
@@ -19,14 +20,20 @@ class StrEnum(str, Enum):
         return str.__str__(self)
 
 
+class AutoblocksEnvVar(StrEnum):
+    API_KEY = "AUTOBLOCKS_API_KEY"
+    INGESTION_KEY = "AUTOBLOCKS_INGESTION_KEY"
+    REPLAY_ID = "AUTOBLOCKS_REPLAY_ID"
+    TRACER_THROW_ON_ERROR = "AUTOBLOCKS_TRACER_THROW_ON_ERROR"
+
+    def get(self) -> Optional[str]:
+        return os.environ.get(self.value)
+
+
 class Provider(StrEnum):
     LOCAL = "local"
     GITHUB = "github"
 
-    def __str__(self) -> str:
-        # https://stackoverflow.com/a/74440069
-        return str.__str__(self)
-
 
 @dataclass(frozen=True)
 class Commit:
@@ -39,6 +46,15 @@ class Commit:
     commit_message: str
 
 
+def encode_uri_component(s: str) -> str:
+    """
+    This should have the same behavior as encodeURIComponent from JS.
+
+    https://stackoverflow.com/a/6618858
+    """
+    return urllib.parse.quote(s, safe="()*!.'")
+
+
 @dataclass(frozen=True)
 class ReplayRun:
     provider: Provider
@@ -73,9 +89,21 @@ class ReplayRun:
         for k, v in d.items():
             if v is None:
                 continue
-            headers[f"X-Autoblocks-Replay-{self.snake_to_kebab(k)}"] = str(v).strip()
+            headers[f"X-Autoblocks-Replay-{self.snake_to_kebab(k)}"] = encode_uri_component(str(v).strip())
         return headers
 
+    @property
+    def html_url(self) -> Optional[str]:
+        base_url = "https://app.autoblocks.ai/replays"
+        if self.provider == Provider.LOCAL:
+            return f"{base_url}/local/run/{encode_uri_component(self.run_id)}"
+        elif self.provider == Provider.GITHUB and self.repo and self.branch_name:
+            repo = encode_uri_component(self.repo)
+            branch = encode_uri_component(self.branch_name)
+            return f"{base_url}/github/repo/{repo}/branch/{branch}"
+
+        return None
+
 
 def run_command(cmd: List[str]) -> str:
     return subprocess.run(cmd, stdout=subprocess.PIPE).stdout.decode("utf8").strip()
@@ -92,6 +120,18 @@ def get_local_branch_name() -> str:
     )
 
 
+def parse_repo_name_from_origin_url(url: str) -> str:
+    """
+    Parses the org and repo name from the origin URL.
+
+    Examples:
+
+    https://github.com/autoblocksai/javascript-sdk.git -> autoblocksai/javascript-sdk
+    git@gitlab.com:gitlab-com/www-gitlab-com.git -> gitlab-com/www-gitlab-com
+    """
+    return "/".join(url.replace(".git", "").split(":")[1].split("/")[-2:])
+
+
 def get_local_repo_name() -> str:
     url = run_command(
         [
@@ -101,12 +141,7 @@ def get_local_repo_name() -> str:
             "origin",
         ]
     )
-    # Parsed the owner/repo string out of the remote URL
-    # Eg. https://github.com/autoblocksai/python-sdk.git -> autoblocksai/python-sdk
-    parts = url.split("/")[-2:]
-    owner, repo = parts
-    repo = repo.split(".")[0]
-    return f"{owner}/{repo}"
+    return parse_repo_name_from_origin_url(url)
 
 
 def get_local_commit_data(sha: Optional[str]) -> Commit:
@@ -141,8 +176,10 @@ def get_local_commit_data(sha: Optional[str]) -> Commit:
         key, value = line.split("=", maxsplit=1)
 
         if key == commit_message_key:
-            # Once we've reached the commit message key, the remaining lines are the commit message
-            data[commit_message_key] = "\n".join([value, *lines])
+            # Once we've reached the commit message key, the remaining lines are the commit message.
+            # We only keep the first line of the commit message, though, since some commit
+            # messages can be very long.
+            data[commit_message_key] = value
             break
 
         data[key] = value
@@ -151,7 +188,15 @@ def get_local_commit_data(sha: Optional[str]) -> Commit:
 
 
 def make_replay_run() -> Optional[ReplayRun]:
+    replay_id = AutoblocksEnvVar.REPLAY_ID.get()
+
     if os.environ.get("GITHUB_ACTIONS"):
+        if replay_id:
+            log.warning(
+                f"Ignoring {AutoblocksEnvVar.REPLAY_ID}={replay_id} "
+                f"environment variable while in GitHub Actions context."
+            )
+
         # GitHub Actions
         g = {k.split("GITHUB_", maxsplit=1)[-1]: v for k, v in os.environ.items() if k.startswith("GITHUB_")}
 
@@ -209,8 +254,7 @@ def make_replay_run() -> Optional[ReplayRun]:
             pull_request_number=pull_request_number,
             pull_request_title=pull_request_title,
         )
-
-    elif replay_id := os.environ.get("AUTOBLOCKS_SIMULATION_ID"):
+    elif replay_id:
         # Local
         try:
             # Try to get local commit data
